@@ -88,7 +88,11 @@ extern mlt_properties mlt_properties_parse_yaml( const char *file );
 extern char *mlt_properties_serialise_yaml( mlt_properties self );
 extern void mlt_properties_lock( mlt_properties self );
 extern void mlt_properties_unlock( mlt_properties self );
+
 extern char *mlt_properties_get_time( mlt_properties, const char* name, mlt_time_format );
+extern char *mlt_properties_frames_to_time( mlt_properties, mlt_position, mlt_time_format );
+extern mlt_position mlt_properties_time_to_frames( mlt_properties, const char* time );
+
 extern mlt_color mlt_properties_get_color( mlt_properties, const char* name );
 extern int mlt_properties_set_color( mlt_properties, const char* name, mlt_color value );
 
@@ -105,4 +109,5 @@ extern mlt_rect mlt_properties_get_rect( mlt_properties self, const char *name )
 extern int mlt_properties_anim_set_rect( mlt_properties self, const char *name, mlt_rect value, int position, int length, mlt_keyframe_type keyframe_type );
 extern mlt_rect mlt_properties_anim_get_rect( mlt_properties self, const char *name, int position, int length );
 
+extern int mlt_properties_from_utf8( mlt_properties properties, const char *name_from, const char *name_to );
 #endif
