@@ -686,8 +686,7 @@ static void query_vcodecs( )
 
 static void on_fatal_error( mlt_properties owner, mlt_consumer consumer )
 {
-	mlt_consumer_stop( consumer );
-	exit( EXIT_FAILURE );
+	mlt_properties_set_int( MLT_CONSUMER_PROPERTIES(consumer), "done", 1 );
 }
 
 int main( int argc, char **argv )
@@ -897,7 +896,7 @@ query_all:
 		// Parse the arguments
 		for ( i = 1; i < argc; i ++ )
 		{
-			if ( !strcmp( argv[ i ], "-jack" ) )
+			if ( !strcmp( argv[ i ], "-jack" ) && consumer )
 			{
 				setup_jack_transport( consumer, profile );
 			}
@@ -988,8 +987,11 @@ query_all:
 	mlt_profile_close( profile );
 
 exit_factory:
-		
+
+// Workaround qmelt on OS X from crashing at exit.
+#if !defined(__MACH__) || !defined(QT_GUI_LIB)
 	mlt_factory_close( );
+#endif
 
 	return 0;
 }
