@@ -259,12 +259,23 @@ static void foreach_consumer_init( mlt_consumer consumer )
 			if ( ( s = mlt_properties_get( properties, key ) ) )
 			{
 				mlt_properties p = mlt_properties_new();
-				int i, count;
-
 				if ( !p ) break;
-				mlt_properties_set( p, "mlt_service", mlt_properties_get( properties, key ) );
+
+				// Terminate mlt_service value at the argument delimiter if supplied.
+				// Needed here instead of just relying upon create_consumer() so that
+				// a properties preset is picked up correctly.
+				char *service = strdup( mlt_properties_get( properties, key ) );
+				char *arg = strchr( service, ':' );
+				if ( arg ) {
+					*arg ++ = '\0';
+					mlt_properties_set( p, "target", arg );
+				}
+				mlt_properties_set( p, "mlt_service", service );
+				free( service );
+
 				snprintf( key, sizeof(key), "%d.", index );
 
+				int i, count;
 				count = mlt_properties_count( properties );
 				for ( i = 0; i < count; i++ )
 				{
@@ -365,6 +376,7 @@ static void foreach_consumer_put( mlt_consumer consumer, mlt_frame frame )
 				// put ideal number of samples into cloned frame
 				int deeply = index > 1 ? 1 : 0;
 				mlt_frame clone_frame = mlt_frame_clone( frame, deeply );
+				mlt_properties clone_props = MLT_FRAME_PROPERTIES( clone_frame );
 				int nested_samples = mlt_sample_calculator( nested_fps, frequency, nested_pos );
 				// -10 is an optimization to avoid tiny amounts of leftover samples
 				nested_samples = nested_samples > current_samples - 10 ? current_samples : nested_samples;
@@ -380,15 +392,21 @@ static void foreach_consumer_put( mlt_consumer consumer, mlt_frame frame )
 					nested_size = 0;
 				}
 				mlt_frame_set_audio( clone_frame, prev_buffer, format, nested_size, mlt_pool_release );
-				mlt_properties_set_int( MLT_FRAME_PROPERTIES(clone_frame), "audio_samples", nested_samples );
-				mlt_properties_set_int( MLT_FRAME_PROPERTIES(clone_frame), "audio_frequency", frequency );
-				mlt_properties_set_int( MLT_FRAME_PROPERTIES(clone_frame), "audio_channels", channels );
+				mlt_properties_set_int( clone_props, "audio_samples", nested_samples );
+				mlt_properties_set_int( clone_props, "audio_frequency", frequency );
+				mlt_properties_set_int( clone_props, "audio_channels", channels );
 
 				// chomp the audio
 				current_samples -= nested_samples;
 				current_size -= nested_size;
 				buffer += nested_size;
 
+				// Fix some things
+				mlt_properties_set_int( clone_props, "meta.media.width",
+					mlt_properties_get_int( MLT_FRAME_PROPERTIES(frame), "width" ) );
+				mlt_properties_set_int( clone_props, "meta.media.height",
+					mlt_properties_get_int( MLT_FRAME_PROPERTIES(frame), "height" ) );
+
 				// send frame to nested consumer
 				mlt_consumer_put_frame( nested, clone_frame );
 				mlt_properties_set_position( nested_props, "_multi_position", ++nested_pos );
