@@ -27,13 +27,13 @@
 /** Do it :-).
 */
 
-static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
+static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
 	int size = *width * *height * 2;
 	*format = mlt_image_yuv422;
 	*image = mlt_pool_alloc( size );
-	mlt_frame_set_image( this, *image, size, mlt_pool_release );
-	uint8_t *wave = mlt_frame_get_waveform( this, *width, *height );
+	mlt_frame_set_image( frame, *image, size, mlt_pool_release );
+	uint8_t *wave = mlt_frame_get_waveform( frame, *width, *height );
 	if ( wave )
 	{
 		uint8_t *p = *image;
@@ -52,7 +52,7 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 /** Filter processing.
 */
 
-static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
+static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
 	mlt_frame_push_get_image( frame, filter_get_image );
 	return frame;
@@ -63,9 +63,9 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 
 mlt_filter filter_audiowave_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	mlt_filter this = mlt_filter_new( );
-	if ( this != NULL )
-		this->process = filter_process;
-	return this;
+	mlt_filter filter = mlt_filter_new( );
+	if ( filter != NULL )
+		filter->process = filter_process;
+	return filter;
 }
 
