@@ -30,17 +30,42 @@
 /** Do it :-).
 */
 
-static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
+static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
+	mlt_filter filter =  (mlt_filter) mlt_frame_pop_service( frame );
+	mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
+	mlt_position position = mlt_filter_get_position( filter, frame );
+	mlt_position length = mlt_filter_get_length2( filter, frame );
+
 	// Get the image
 	*format = mlt_image_yuv422;
-	int error = mlt_frame_get_image( this, image, format, width, height, 1 );
+	int error = mlt_frame_get_image( frame, image, format, width, height, 1 );
 
 	// Only process if we have no error and a valid colour space
 	if ( error == 0 )
 	{
-		// Get the brightness level
-		double level = mlt_properties_get_double( MLT_FRAME_PROPERTIES( this ), "brightness" );
+		double level = 1.0;
+
+		// Use animated "level" property only if it has been set since init
+		char* level_property = mlt_properties_get( MLT_FILTER_PROPERTIES( filter ), "level" );
+		if ( level_property != NULL )
+		{
+			level = mlt_properties_anim_get_double( properties, "level", position, length );
+		}
+		else
+		{
+			// Get level using old "start,"end" mechanics
+			// Get the starting brightness level
+			level = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( filter ), "start" ) );
+
+			// If there is an end adjust gain to the range
+			if ( mlt_properties_get( MLT_FILTER_PROPERTIES( filter ), "end" ) != NULL )
+			{
+				// Determine the time position of this frame in the transition duration
+				double end = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( filter ), "end" ) );
+				level += ( end - level ) * mlt_filter_get_progress( filter, frame );
+			}
+		}
 
 		// Only process if level is something other than 1
 		if ( level != 1.0 )
@@ -65,21 +90,9 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 /** Filter processing.
 */
 
-static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
+static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
-	// Get the starting brightness level
-	double level = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( this ), "start" ) );
-
-	// If there is an end adjust gain to the range
-	if ( mlt_properties_get( MLT_FILTER_PROPERTIES( this ), "end" ) != NULL )
-	{
-		// Determine the time position of this frame in the transition duration
-		double end = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( this ), "end" ) );
-		level += ( end - level ) * mlt_filter_get_progress( this, frame );
-	}
-
-	// Push the frame filter
-	mlt_properties_set_double( MLT_FRAME_PROPERTIES( frame ), "brightness", level );
+	mlt_frame_push_service( frame, filter );
 	mlt_frame_push_get_image( frame, filter_get_image );
 
 	return frame;
@@ -90,12 +103,13 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 
 mlt_filter filter_brightness_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	mlt_filter this = mlt_filter_new( );
-	if ( this != NULL )
+	mlt_filter filter = mlt_filter_new( );
+	if ( filter != NULL )
 	{
-		this->process = filter_process;
-		mlt_properties_set( MLT_FILTER_PROPERTIES( this ), "start", arg == NULL ? "1" : arg );
+		filter->process = filter_process;
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "start", arg == NULL ? "1" : arg );
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "level", NULL );
 	}
-	return this;
+	return filter;
 }
 
