@@ -322,10 +322,10 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 /** Filter processing.
 */
 
-static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
+static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
 	// Push the filter
-	mlt_frame_push_service( frame, this );
+	mlt_frame_push_service( frame, filter );
 
 	// Register the get image method
 	mlt_frame_push_get_image( frame, filter_get_image );
@@ -340,21 +340,21 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 mlt_filter filter_data_show_init( mlt_profile profile, mlt_service_type type, const char *id, void *arg )
 {
 	// Create the filter
-	mlt_filter this = mlt_filter_new( );
+	mlt_filter filter = mlt_filter_new( );
 
 	// Initialise it
-	if ( this != NULL )
+	if ( filter != NULL )
 	{
 		// Get the properties
-		mlt_properties properties = MLT_FILTER_PROPERTIES( this );
+		mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
 
 		// Assign the argument (default to titles)
 		mlt_properties_set( properties, "resource", arg == NULL ? NULL : arg );
 
 		// Specify the processing method
-		this->process = filter_process;
+		filter->process = filter_process;
 	}
 
-	return this;
+	return filter;
 }
 
