@@ -237,10 +237,8 @@ plugin_mgr_get_path_plugins (plugin_mgr_t * plugin_mgr)
     ladspa_path = g_strdup ("/usr/local/lib/ladspa:/usr/lib/ladspa:/usr/lib64/ladspa");
 #endif
   
-  dir = strtok (ladspa_path, ":");
-  do
+  for (dir = strtok (ladspa_path, ":"); dir; dir = strtok (NULL, ":"))
     plugin_mgr_get_dir_plugins (plugin_mgr, dir);
-  while ((dir = strtok (NULL, ":")));
 
   g_free (ladspa_path);
 }
