@@ -34,13 +34,14 @@ static inline int clamp( int v, int l, int u )
 /** Do it :-).
 */
 
-static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
+static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
 	// Get the image
-	mlt_filter filter = mlt_frame_pop_service( this );
+	mlt_filter filter = mlt_frame_pop_service( frame );
+
 	int mask = mlt_properties_get_int( MLT_FILTER_PROPERTIES( filter ), "alpha" );
 	*format = mlt_image_yuv422;
-	int error = mlt_frame_get_image( this, image, format, width, height, 1 );
+	int error = mlt_frame_get_image( frame, image, format, width, height, 1 );
 
 	// Only process if we have no error and a valid colour space
 	if ( error == 0 )
@@ -57,7 +58,7 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 
 		if ( mask )
 		{
-			uint8_t *alpha = mlt_frame_get_alpha_mask( this );
+			uint8_t *alpha = mlt_frame_get_alpha_mask( frame );
 			int size = *width * *height;
 			memset( alpha, mask, size );
 		}
@@ -69,10 +70,10 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 /** Filter processing.
 */
 
-static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
+static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
 	// Push the frame filter
-	mlt_frame_push_service( frame, this );
+	mlt_frame_push_service( frame, filter );
 	mlt_frame_push_get_image( frame, filter_get_image );
 	return frame;
 }
@@ -82,9 +83,11 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 
 mlt_filter filter_invert_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	mlt_filter this = mlt_filter_new( );
-	if ( this != NULL )
-		this->process = filter_process;
-	return this;
+	mlt_filter filter = mlt_filter_new( );
+	if ( filter != NULL )
+	{
+		filter->process = filter_process;
+	}
+	return filter;
 }
 
