@@ -28,14 +28,17 @@
 /** Do it :-).
 */
 
-static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
+static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
 	// Get the filter
-	mlt_filter filter = mlt_frame_pop_service( this );
+	mlt_filter filter = mlt_frame_pop_service( frame );
+	mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
+	mlt_position position = mlt_filter_get_position( filter, frame );
+	mlt_position length = mlt_filter_get_length2( filter, frame );
 
 	// Get the image
 	*format = mlt_image_yuv422;
-	int error = mlt_frame_get_image( this, image, format, width, height, 1 );
+	int error = mlt_frame_get_image( frame, image, format, width, height, 1 );
 
 	// Only process if we have no error and a valid colour space
 	if ( error == 0 && *image )
@@ -48,8 +51,8 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 		int t;
 
 		// Get u and v values
-		int u = mlt_properties_get_int( MLT_FILTER_PROPERTIES( filter ), "u" );
-		int v = mlt_properties_get_int( MLT_FILTER_PROPERTIES( filter ), "v" );
+		int u = mlt_properties_anim_get_int( properties, "u", position, length );
+		int v = mlt_properties_anim_get_int( properties, "v", position, length );
 
 		// Loop through image
 		while( h -- )
@@ -76,10 +79,10 @@ static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *
 /** Filter processing.
 */
 
-static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
+static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 {
 	// Push the frame filter
-	mlt_frame_push_service( frame, this );
+	mlt_frame_push_service( frame, filter );
 	mlt_frame_push_get_image( frame, filter_get_image );
 	return frame;
 }
@@ -89,13 +92,13 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 
 mlt_filter filter_sepia_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	mlt_filter this = mlt_filter_new( );
-	if ( this != NULL )
+	mlt_filter filter = mlt_filter_new( );
+	if ( filter != NULL )
 	{
-		this->process = filter_process;
-		mlt_properties_set( MLT_FILTER_PROPERTIES( this ), "u", "75" );
-		mlt_properties_set( MLT_FILTER_PROPERTIES( this ), "v", "150" );
+		filter->process = filter_process;
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "u", "75" );
+		mlt_properties_set( MLT_FILTER_PROPERTIES( filter ), "v", "150" );
 	}
-	return this;
+	return filter;
 }
 
